@@ -63,20 +63,16 @@ class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
 
     metadata = metadata_module.PrimitiveMetadata({
         'id': '69845479-0b61-3578-b382-972cd0e61d69',
-        'version': '2.0.13',
+        'version': '2.0.14',
         'name': 'IPCMB feature selector',
         'keywords': ['rpi primitives'],
         'source': {
-            'name': 'RPI',
-            'uris': [
-                'rpi_featureSelection_python_tools',
-                'rpi_feature_selection_toolbox'
-            ],
+            'name': 'RPI'
         },
         'installation':[{
             'type': 'PIP',
             'package': 'rpi_featureSelection_python_tools',
-	    'version': '2.0.13'
+	    'version': '2.0.14'
         }],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.IPCMBplus_Selector',
         'algorithm_types': 'MINIMUM_REDUNDANCY_FEATURE_SELECTION',
